import React from 'react'

import fuzzy from 'fuzzy';
import InfiniteScroll from 'react-infinite-scroller';

import ListFilter from './filter'
import ListPoster from './poster'

export default class ListPosters extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      items: 30,
      hasMore: true,
    };
    this.loadMore = this.loadMore.bind(this);
  }
  loadMore() {
    if (!this.state.hasMore || this.props.data.length === 0) {
      return
    }

    const addItems = 30;
    if (this.state.items + addItems >= this.props.data.length) {
      this.setState({
        items: this.props.data.length,
        hasMore: false,
      });
    } else {
      this.setState({
        items: this.state.items + addItems,
        hasMore: true,
      });
    }
  }

  render() {
    let elmts = this.props.data.slice();
    const listSize = elmts.length;
    const colSize = (listSize !== 0) ? "col-xs-5 col-md-8" : "col-xs-12";

    // Filter the list of elements
    if (this.props.filter !== "") {
      const filtered = fuzzy.filter(this.props.filter, elmts, {
        extract: (el) => el.title
      });
      elmts = filtered.map((el) => el.original);
    } else {
      elmts = elmts.slice(0, this.state.items);
    }

    return (
      <div className={colSize}>
        <ListFilter
          listSize={listSize}
          formModel={this.props.formModel}
          controlModel={this.props.controlModel}
          controlPlaceHolder={this.props.controlPlaceHolder}
        />
        {elmts.length === 0 &&
            <div className="jumbotron">
              <h2>No result</h2>
            </div>
        }
        <InfiniteScroll
          hasMore={this.state.hasMore}
          loadMore={this.loadMore}
          className="row"
        >
          {elmts.map(function(el, index) {
            const selected = (el.imdb_id === this.props.selectedImdbId) ? true : false;
            return (
              <ListPoster
                index={index}
                data={el}
                key={el.imdb_id}
                selected={selected}
                onClick={() => this.props.onClick(el.imdb_id)}
              />
            )}
            , this)}
        </InfiniteScroll>
      </div>
    );
  }
}
